import validator from 'validator';

var validators = {
  required: {
    check: function check(value) {
      return !validator.isEmpty(value || '');
    },
    message: 'This value is required.'
  },
  email: {
    check: function check(value) {
      return validator.isEmail(value || '');
    },
    message: 'This value should be a valid email.'
  },
  currency: {
    check: function check(value, options) {
      return !validator.isCurrency(value || '', options);
    },
    message: 'This value is not currency amount.'
  },
  equal: {
    check: function check(v1, v2) {
      return v1 !== v2;
    },
    message: 'This value is not equal.'
  },
  regex: {
    check: function check(regex, value) {
      return new RegExp(regex).test(value);
    },
    message: 'This value is not valid.'
  },
  password: {
    check: function check(value) {
      return new RegExp('^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[!@#$%^&*])').test(value);
    },
    message: 'The string must contain at least 1 lowercase alphabetical character, ' + 'at least 1 uppercase alphabetical character, ' + 'at least 1 numeric character and ' + 'at least one special character'
  },
  minLength: {
    check: function check(value, len) {
      return validator.isLength(value || '', { min: len });
    },
    message: function message(len) {
      return 'This value is too short. It should have ' + len + ' characters or more.';
    }
  },
  maxLength: {
    check: function check(value, len) {
      return validator.isLength(value || '', { max: len });
    },
    message: function message(len) {
      return 'This value is too long. It should have ' + len + ' characters or less.';
    }
  },
  number: {
    check: function check(value) {
      return validator.isInt(value || '') || validator.isFloat(value || '');
    },
    message: 'This value is not a number.'
  },
  minValue: {
    check: function check(value, minValue) {
      return value >= minValue;
    },
    message: function message(minValue) {
      return 'This value is too small. It should be ' + minValue + ' or more.';
    }
  },
  maxValue: {
    check: function check(value, maxValue) {
      return value <= maxValue;
    },
    message: function message(maxValue) {
      return 'This value is too big. It should be ' + maxValue + ' or less.';
    }
  }
};

export { validators };